@@ -23,7 +23,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * $Id: openbsd.c 1090 2008-03-31 04:56:39Z brenden1 $ */
+ * $Id: openbsd.c 1193 2008-06-21 20:37:58Z ngarofil $ */
 
 #include <sys/dkstat.h>
 #include <sys/param.h>
@@ -49,9 +49,6 @@
 #include <fcntl.h>
 #include <ifaddrs.h>
 #include <limits.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include <unistd.h>
 #include <machine/apmvar.h>
 
@@ -178,6 +175,7 @@ void update_meminfo()
 
 	info.memmax = pagetok(vmtotal.t_rm) + pagetok(vmtotal.t_free);
 	info.mem = pagetok(vmtotal.t_rm);
+	info.memeasyfree = info.memfree = info.memmax - info.mem;
 
 	if ((swapmode(&swap_used, &swap_avail)) >= 0) {
 		info.swapmax = swap_avail;
@@ -628,7 +626,8 @@ void update_wifi_stats()
 		bzero(&ifmr, sizeof(ifmr));
 		strlcpy(ifmr.ifm_name, ifa->ifa_name, IFNAMSIZ);
 		if (ioctl(s, SIOCGIFMEDIA, (caddr_t) &ifmr) < 0) {
-			goto cleanup;
+			close(s);
+			return;
 		}
 
 		/* We can monitor only wireless interfaces
@@ -716,7 +715,7 @@ inline void proc_find_top(struct process **cpu, struct process **mem)
 	for (i = 0; i < n_processes; i++) {
 		if (!((p[i].p_flag & P_SYSTEM)) && p[i].p_comm != NULL) {
 			processes[j].pid = p[i].p_pid;
-			processes[j].name = strdup(p[i].p_comm);
+			processes[j].name = strndup(p[i].p_comm, text_buffer_size);
 			processes[j].amount = 100.0 * p[i].p_pctcpu / FSCALE;
 			processes[j].totalmem = (float) (p[i].p_vm_rssize * pagesize /
 				(float) total_pages) * 100.0;
@@ -732,7 +731,7 @@ inline void proc_find_top(struct process **cpu, struct process **mem)
 		tmp->pid = processes[i].pid;
 		tmp->amount = processes[i].amount;
 		tmp->totalmem = processes[i].totalmem;
-		tmp->name = strdup(processes[i].name);
+		tmp->name = strndup(processes[i].name, text_buffer_size);
 
 		ttmp = mem[i];
 		mem[i] = tmp;
@@ -750,7 +749,7 @@ inline void proc_find_top(struct process **cpu, struct process **mem)
 		tmp->pid = processes[i].pid;
 		tmp->amount = processes[i].amount;
 		tmp->totalmem = processes[i].totalmem;
-		tmp->name = strdup(processes[i].name);
+		tmp->name = strndup(processes[i].name, text_buffer_size);
 
 		ttmp = cpu[i];
 		cpu[i] = tmp;
